:tocdepth: 2

.. _authors:

Authors
=======

py7zr is written and maintained by Hiroshi Miura <miurahr@linux.com>

Contributors, listed alphabetically, are:

* Alan Lee -- Update documentation
* Alexander Kapshuna -- Fix shutil integration (#353)
* @andrebrait -- Fix exception for empty 7z file (#118)
* Antoine C -- Support Python 3.12 and later (#550)
* @amarcu5 -- Fix error when large compressed headers (#281)
* c.foster -- Default exceptions to include the exception type
* chigusa -- Fix UTF-16 path parsing for extraction (#391)
* @DoNCK -- Fix extraction of hidden dot files(#448)
* François Freitag -- Improve shutil interface support (#583, #584)
* Jasper Lievisse Adriaanse -- Update document
* Joachim Bauch -- pylzma originator
* John King -- Fix 64bit os detection (#580)
* Kazuya Fujioka -- Fix zero file problem
* Kyle Altendorf -- Fix multithreading problem (#82)
* Martin Larralde -- Fix writef method (#397)
* Megan Leet -- Fix infinite loop when extraction (#354)
* Michael V. Scovetta -- Help improving security concerns (#623)
* @Michał -- Fix pyannotate with removal (#588)
* Matteo Cosentino -- Help improving security concerns (#480)
* Nikolaos Episkopos -- Add recursive subdirectories extraction (#585)
* @padremayi -- Fix crash on wrong creation time in archive (#275)
* @Ravencentric -- Fix "a" mode, support Python 3.13, modernize codes, and improve CI (#604, #619)
* @royopa -- Fix typo (#108)
* Sergei -- Update report_update() (#558)
* T. Yamada -- Deflate64 decompression (#399)
* Vlad Firoiu -- Speed-up extraction when number of files is very large(#555)
* @Zoynels -- BytesIO dictionary API (#111, #119) (removed in v1.0.0-rc2)
